==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDetailDescription } from "./WebFloatingPaneResizeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a == null) {
                WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.c(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a);
            WebSplitPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebSplitPane");
            a.item("ResizerLocation", "ExportedType:string:ResizerLocation");
            a.item("ResizerLocation@stringUnion", "WebComponents;React");
            a.item("ResizerLocation@names", "Top;Bottom;Left;Right;TopLeft;TopRight;BottomLeft;BottomRight");
        }
        static d(a) {
            WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebFloatingPaneResizeEventArgsDetail", () => new WebFloatingPaneResizeEventArgsDetailDescription());
            a.ac("WebFloatingPaneResizeEventArgsDetail", WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata, 'WebFloatingPaneResizeEventArgsDetailDescriptionMetadata');
    WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a = null;
    return WebFloatingPaneResizeEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDetailDescription } from "./WebFloatingPaneResizeEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a == null) {
                WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.c(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a);
            WebSplitPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeEventArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("SourcePane", "ExportedType:WebSplitPane");
            a.item("ResizerLocation", "ExportedType:string:ResizerLocation");
            a.item("ResizerLocation@stringUnion", "WebComponents;React");
            a.item("ResizerLocation@names", "Top;Bottom;Left;Right;TopLeft;TopRight;BottomLeft;BottomRight");
        }
        static d(a) {
            WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebFloatingPaneResizeEventArgsDetail", () => new WebFloatingPaneResizeEventArgsDetailDescription());
            a.ad("WebFloatingPaneResizeEventArgsDetail", WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeEventArgsDetailDescriptionMetadata, 'WebFloatingPaneResizeEventArgsDetailDescriptionMetadata');
    WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.a = null;
    return WebFloatingPaneResizeEventArgsDetailDescriptionMetadata;
})();
